@@ -1,5 +1,5 @@
 import requests
-url = "https://api.replstories.xyz/mod"
+url = "https://replstories.xyz/mod"
 
 class init:
 	def __init__(self, userid):  
